var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from "react";
import { Button, IconButton, withStyles } from "@material-ui/core";
import { getErrorMessages, getErrorsForPointer } from "../EditorErrorMessages";
import { EditorFieldParentType } from "../EditorField";
import { DeleteOutlined, KeyboardArrowDown, KeyboardArrowRight } from "@material-ui/icons";
import clsx from "clsx";
import CollapsibleSection from "../CollapsibleSection";
import CollapsibleSectionHeader from "../CollapsibleSectionHeader";
import EditorField from "../EditorField/EditorField";
export var styles = {
    root: {
        width: "100%"
    },
    rootProperty: {
        "border-left": "4px solid #e5e5e5",
        padding: "0 16px 0 15px",
        "margin-bottom": "17px",
        "box-shadow": "0 1px 3px 0 rgb(0 0 0 / 20%), 0 1px 1px 0 rgb(0 0 0 / 14%), 0 2px 1px -1px rgb(0 0 0 / 12%)"
    },
    btn: {
        "max-width": "100%",
        margin: "5px 2px 8px",
        "text-transform": "none",
        "border-radius": "3px",
        "font-size": 13,
        padding: "0 15px",
        height: 24,
        "line-height": 24,
        "background-color": "#e5e5e5",
        "min-height": 24,
        color: "#29333f",
        "font-weight": 500,
        "&:hover": {
            "background-color": "#1ab0f9",
            color: "#fff"
        }
    },
    label: {
        height: "100%",
        "line-height": 0
    },
    list: {
        "list-style": "none",
        "margin-block-start": 0,
        "margin-block-end": 0,
        margin: 0,
        padding: 0,
        "box-sizing": "border-box"
    },
    listItem: {
        "margin-left": "15px",
        display: "flex"
    },
    removeBtn: {
        "background-color": "transparent",
        color: "transparent",
        "&:hover": {
            "background-color": "transparent",
            color: "grey"
        }
    },
    listCards: {
        display: "flex"
    },
    removeBtnHovered: {
        color: "grey"
    }
};
var EditorListField = function (props) {
    var _a;
    var schema = props.schema, value = props.value, onChange = props.onChange, classes = props.classes, pointer = props.pointer, errorReport = props.errorReport, registry = props.registry;
    var minItems = schema.minItems || 0;
    var maxItems = schema.maxItems;
    var _b = React.useState(true), isExpanded = _b[0], setExpandedState = _b[1];
    var _c = React.useState(-1), isHovering = _c[0], setHovering = _c[1];
    var _d = React.useState(value || schema.default || new Array(minItems).fill("")), items = _d[0], setItems = _d[1];
    var handleChange = React.useCallback(function (newValue, index) {
        if (newValue === "") {
            newValue = undefined;
        }
        var newItems = items.slice();
        newItems[index] = newValue || "";
        setItems(newItems);
        if (onChange) {
            onChange(newItems);
        }
    }, [items, onChange]);
    var addListItem = React.useCallback(function () {
        setItems(items.concat([""]));
    }, [items, setItems]);
    var removeItem = React.useCallback(function (index) {
        var newItems = items.filter(function (el, ind) { return ind !== index; });
        setItems(newItems);
        if (onChange) {
            onChange(newItems);
        }
    }, [items, setItems, onChange]);
    var errors = getErrorsForPointer(pointer, errorReport);
    var errorMessages = getErrorMessages(schema, errors, registry);
    var handleExpand = function (expanded) {
        setExpandedState(expanded);
    };
    var Icon = isExpanded ? KeyboardArrowDown : KeyboardArrowRight;
    return schema.items.type === "string" ? (React.createElement("div", { className: clsx(classes.rootProperty) },
        React.createElement(CollapsibleSection, { onChange: handleExpand },
            React.createElement(CollapsibleSectionHeader, { icon: Icon, title: schema.title }),
            React.createElement("ul", { className: clsx(classes.list, (_a = {},
                    _a[classes.listCards] = schema.items.type !== "string",
                    _a)) }, items.map(function (item, index) {
                var _a;
                return (React.createElement("li", { key: schema.title + " " + (index + 1), className: clsx(classes.listItem), 
                    // tslint:disable-next-line
                    onMouseEnter: function () { return setHovering(index); }, 
                    // tslint:disable-next-line
                    onMouseLeave: function () { return setHovering(-1); } },
                    React.createElement(EditorField, { pointer: pointer, errorReport: errorReport, parentType: EditorFieldParentType.EDITOR_ROOT, schema: __assign({ title: schema.title + " " + (index + 1), description: schema.description }, schema.items), value: item, registry: registry, required: false, 
                        // tslint:disable-next-line
                        onChange: function (propertyValue) { return handleChange(propertyValue, index); } }),
                    React.createElement(IconButton, { className: clsx(classes.removeBtn, (_a = {},
                            _a[classes.removeBtnHovered] = isHovering === index,
                            _a)), disableRipple: true, color: "secondary", "aria-label": "remove", 
                        // tslint:disable-next-line
                        onClick: function () { return removeItem(index); } },
                        React.createElement(DeleteOutlined, null))));
            })),
            React.createElement(Button, { color: "secondary", variant: "contained", onClick: addListItem, classes: {
                    root: classes.btn,
                    label: classes.label
                }, disabled: maxItems && maxItems === items.length }, "Add " + schema.title)))) : null;
};
export default withStyles(styles, { name: "DcEditorListField" })(EditorListField);
