import React, { useState } from "react";
import { FormControl, FormHelperText, TextField as MuiTextField, withStyles } from "@material-ui/core";
import clsx from "clsx";
import { getErrorMessages, getErrorsForPointer } from "../EditorErrorMessages";
export var styles = {
    root: {
        width: "100%"
    },
    input: {
        "-moz-appearance": "textfield",
        "&::-webkit-outer-spin-button": {
            "-webkit-appearance": "none",
            margin: 0
        },
        "&::-webkit-inner-spin-button": {
            "-webkit-appearance": "none",
            margin: 0
        }
    }
};
var EditorNumberField = function (props) {
    var schema = props.schema, value = props.value, readonly = props.readonly, required = props.required, disabled = props.disabled, onChange = props.onChange, classes = props.classes, pointer = props.pointer, errorReport = props.errorReport, registry = props.registry;
    var errors = getErrorsForPointer(pointer, errorReport);
    var _a = useState(getErrorMessages(schema, errors, registry)), errorMessages = _a[0], setError = _a[1];
    var handleChange = React.useCallback(function (event) {
        var newValue = event.target.value;
        if (newValue === "") {
            newValue = undefined;
        }
        if (schema.maximum && newValue > schema.maximum && registry) {
            setError([
                registry.errorMessages.maximum(schema, {
                    message: "",
                    pointer: pointer,
                    schema: schema,
                    data: {
                        keyword: "length",
                        params: {
                            limit: schema.maximum
                        }
                    }
                })
            ]);
        }
        else if (schema.minimum && newValue < schema.minimum && registry) {
            setError([
                registry.errorMessages.minimum(schema, {
                    message: "",
                    pointer: pointer,
                    schema: schema,
                    data: {
                        keyword: "length",
                        params: {
                            limit: schema.minimum
                        }
                    }
                })
            ]);
        }
        else {
            setError([]);
        }
        if (onChange) {
            onChange(newValue);
        }
    }, [onChange]);
    return (React.createElement(FormControl, { className: classes.root },
        React.createElement(MuiTextField, { autoComplete: "off", label: schema.title || "", disabled: disabled, required: required, onChange: handleChange, type: "number", defaultValue: schema.default, inputProps: {
                readOnly: readonly,
                "aria-label": schema.description || "",
                className: clsx(classes.input)
            }, error: errorMessages.length > 0, value: value }),
        React.createElement(FormHelperText, { error: errorMessages.length > 0 }, errorMessages.length ? errorMessages[0] : schema.description)));
};
export default withStyles(styles, { name: "DcEditorNumberField" })(EditorNumberField);
