import EditorCheckboxField from "../EditorCheckboxField/EditorCheckboxField";
import EditorColorField from "../EditorColorField/EditorColorField";
import EditorConstField from "../EditorConstField";
import EditorContentLinkField from "../EditorContentLinkField";
import EditorContentReferenceField from "../EditorContentReferenceField";
import EditorDropdownField from "../EditorDropdownField";
import EditorListField from "../EditorListField/EditorListField";
import EditorMediaLinkField from "../EditorMediaLinkField";
import EditorNumberField from "../EditorNumberField/EditorNumberField";
import EditorObjectField from "../EditorObjectField/EditorObjectField";
import EditorOneOfField, { isOneOfField } from "../EditorOneOfField/EditorOneOfField";
import EditorTextField from "../EditorTextField/EditorTextField";
export function forType(type, component) {
    return function (schema) {
        if (schema.type === type) {
            return component;
        }
    };
}
export function forFormat(type, format, component) {
    return function (schema) {
        if (schema.format === format && schema.type === type) {
            return component;
        }
    };
}
export function forExtensionName(name, component) {
    return function (schema) {
        if (schema["ui:extension"] && schema["ui:extension"].name === name) {
            return component;
        }
    };
}
export function forBuiltInSchema(builtInSchemas, component) {
    return function (schema) {
        if (schema && schema.allOf) {
            var schemas = schema.allOf.map(function (subSchema) { return subSchema.$ref; });
            for (var _i = 0, builtInSchemas_1 = builtInSchemas; _i < builtInSchemas_1.length; _i++) {
                var builtInSchema = builtInSchemas_1[_i];
                if (schemas.indexOf(builtInSchema) !== -1) {
                    return component;
                }
            }
        }
    };
}
export function getComponentForSchema(schema, registry) {
    if (registry) {
        for (var _i = 0, _a = registry.fieldProviders; _i < _a.length; _i++) {
            var provider = _a[_i];
            var control = provider(schema);
            if (control) {
                return control;
            }
        }
    }
}
export function getDefaultRegistry() {
    return {
        fieldProviders: [
            // one of
            function (schema) {
                if (isOneOfField(schema)) {
                    return EditorOneOfField;
                }
            },
            function (schema) {
                if (schema && schema.const) {
                    return EditorConstField;
                }
            },
            // dropdown
            function (schema) { return (schema.enum ? EditorDropdownField : undefined); },
            // list field
            forType("array", EditorListField),
            // number field
            forType("number", EditorNumberField),
            // boolean field
            forType("boolean", EditorCheckboxField),
            // text field
            forFormat("string", "color", EditorColorField),
            // text field
            forType("string", EditorTextField),
            // media link
            forBuiltInSchema([
                "http://bigcontent.io/cms/schema/v1/core#/definitions/image-link",
                "http://bigcontent.io/cms/schema/v1/core#/definitions/video-link"
            ], EditorMediaLinkField),
            // content-link
            forBuiltInSchema(["http://bigcontent.io/cms/schema/v1/core#/definitions/content-link"], EditorContentLinkField),
            // content-reference
            forBuiltInSchema(["http://bigcontent.io/cms/schema/v1/core#/definitions/content-reference"], EditorContentReferenceField),
            // object
            forType("object", EditorObjectField)
        ],
        errorMessages: getDefaultErrorMessages()
    };
}
export function getDefaultErrorMessages() {
    return {
        maxLength: function (schema, error) {
            var errorData = error.data;
            var params = errorData.params;
            return schema.title + " is too long (it should be at most " + params.limit + " characters";
        },
        minLength: function (schema, error) {
            var errorData = error.data;
            var params = errorData.params;
            return schema.title + " is too short (it should be at least " + params.limit + " characters";
        },
        pattern: function (schema, error) {
            var errorData = error.data;
            var params = errorData.params;
            return "Must match the format for " + params.pattern;
        },
        minimum: function (schema, error) {
            var errorData = error.data;
            var params = errorData.params;
            return (schema.title || "Field") + " should be at least " + params.limit;
        },
        maximum: function (schema, error) {
            var errorData = error.data;
            var params = errorData.params;
            return (schema.title || "Field") + " should be at most " + params.limit;
        }
    };
}
